==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/ec2/IPAMResourceDiscoveryReference.java <==
package software.amazon.awscdk.interfaces.ec2;

/**
 * A reference to a IPAMResourceDiscovery resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ec2.*;
 * IPAMResourceDiscoveryReference iPAMResourceDiscoveryReference = Map.of(
 *         "ipamResourceDiscoveryId", "ipamResourceDiscoveryId");
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.254Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ec2.IPAMResourceDiscoveryReference")
@software.amazon.jsii.Jsii.Proxy(IPAMResourceDiscoveryReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IPAMResourceDiscoveryReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The IpamResourceDiscoveryId of the IPAMResourceDiscovery resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getIpamResourceDiscoveryId();

    /**
     * @return a {@link Builder} of {@link IPAMResourceDiscoveryReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IPAMResourceDiscoveryReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<IPAMResourceDiscoveryReference> {
        java.lang.String ipamResourceDiscoveryId;

        /**
         * Sets the value of {@link IPAMResourceDiscoveryReference#getIpamResourceDiscoveryId}
         * @param ipamResourceDiscoveryId The IpamResourceDiscoveryId of the IPAMResourceDiscovery resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ipamResourceDiscoveryId(java.lang.String ipamResourceDiscoveryId) {
            this.ipamResourceDiscoveryId = ipamResourceDiscoveryId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IPAMResourceDiscoveryReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public IPAMResourceDiscoveryReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IPAMResourceDiscoveryReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IPAMResourceDiscoveryReference {
        private final java.lang.String ipamResourceDiscoveryId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ipamResourceDiscoveryId = software.amazon.jsii.Kernel.get(this, "ipamResourceDiscoveryId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ipamResourceDiscoveryId = java.util.Objects.requireNonNull(builder.ipamResourceDiscoveryId, "ipamResourceDiscoveryId is required");
        }

        @Override
        public final java.lang.String getIpamResourceDiscoveryId() {
            return this.ipamResourceDiscoveryId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ipamResourceDiscoveryId", om.valueToTree(this.getIpamResourceDiscoveryId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ec2.IPAMResourceDiscoveryReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IPAMResourceDiscoveryReference.Jsii$Proxy that = (IPAMResourceDiscoveryReference.Jsii$Proxy) o;

            return this.ipamResourceDiscoveryId.equals(that.ipamResourceDiscoveryId);
        }

        @Override
        public final int hashCode() {
            int result = this.ipamResourceDiscoveryId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/ec2/IPAMResourceDiscoveryReference.java <==
package software.amazon.awscdk.interfaces.ec2;

/**
 * A reference to a IPAMResourceDiscovery resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ec2.*;
 * IPAMResourceDiscoveryReference iPAMResourceDiscoveryReference = Map.of(
 *         "ipamResourceDiscoveryArn", "ipamResourceDiscoveryArn",
 *         "ipamResourceDiscoveryId", "ipamResourceDiscoveryId");
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:32.422Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ec2.IPAMResourceDiscoveryReference")
@software.amazon.jsii.Jsii.Proxy(IPAMResourceDiscoveryReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IPAMResourceDiscoveryReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the IPAMResourceDiscovery resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getIpamResourceDiscoveryArn();

    /**
     * The IpamResourceDiscoveryId of the IPAMResourceDiscovery resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getIpamResourceDiscoveryId();

    /**
     * @return a {@link Builder} of {@link IPAMResourceDiscoveryReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IPAMResourceDiscoveryReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<IPAMResourceDiscoveryReference> {
        java.lang.String ipamResourceDiscoveryArn;
        java.lang.String ipamResourceDiscoveryId;

        /**
         * Sets the value of {@link IPAMResourceDiscoveryReference#getIpamResourceDiscoveryArn}
         * @param ipamResourceDiscoveryArn The ARN of the IPAMResourceDiscovery resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ipamResourceDiscoveryArn(java.lang.String ipamResourceDiscoveryArn) {
            this.ipamResourceDiscoveryArn = ipamResourceDiscoveryArn;
            return this;
        }

        /**
         * Sets the value of {@link IPAMResourceDiscoveryReference#getIpamResourceDiscoveryId}
         * @param ipamResourceDiscoveryId The IpamResourceDiscoveryId of the IPAMResourceDiscovery resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ipamResourceDiscoveryId(java.lang.String ipamResourceDiscoveryId) {
            this.ipamResourceDiscoveryId = ipamResourceDiscoveryId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IPAMResourceDiscoveryReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public IPAMResourceDiscoveryReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IPAMResourceDiscoveryReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IPAMResourceDiscoveryReference {
        private final java.lang.String ipamResourceDiscoveryArn;
        private final java.lang.String ipamResourceDiscoveryId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ipamResourceDiscoveryArn = software.amazon.jsii.Kernel.get(this, "ipamResourceDiscoveryArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ipamResourceDiscoveryId = software.amazon.jsii.Kernel.get(this, "ipamResourceDiscoveryId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ipamResourceDiscoveryArn = java.util.Objects.requireNonNull(builder.ipamResourceDiscoveryArn, "ipamResourceDiscoveryArn is required");
            this.ipamResourceDiscoveryId = java.util.Objects.requireNonNull(builder.ipamResourceDiscoveryId, "ipamResourceDiscoveryId is required");
        }

        @Override
        public final java.lang.String getIpamResourceDiscoveryArn() {
            return this.ipamResourceDiscoveryArn;
        }

        @Override
        public final java.lang.String getIpamResourceDiscoveryId() {
            return this.ipamResourceDiscoveryId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ipamResourceDiscoveryArn", om.valueToTree(this.getIpamResourceDiscoveryArn()));
            data.set("ipamResourceDiscoveryId", om.valueToTree(this.getIpamResourceDiscoveryId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ec2.IPAMResourceDiscoveryReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IPAMResourceDiscoveryReference.Jsii$Proxy that = (IPAMResourceDiscoveryReference.Jsii$Proxy) o;

            if (!ipamResourceDiscoveryArn.equals(that.ipamResourceDiscoveryArn)) return false;
            return this.ipamResourceDiscoveryId.equals(that.ipamResourceDiscoveryId);
        }

        @Override
        public final int hashCode() {
            int result = this.ipamResourceDiscoveryArn.hashCode();
            result = 31 * result + (this.ipamResourceDiscoveryId.hashCode());
            return result;
        }
    }
}
